@@ -136,7 +136,9 @@ class levelplugin(hildondesktop.HomePluginItem):
         self.pixbufM = gtk.gdk.pixbuf_new_from_file ('/home/opt/levelball/img/Base3.png')
      
      
-        self.imageP = gtk.image_new_from_file('AppletConfigureButton.png')
+        self.imageCONF = gtk.image_new_from_file('/home/opt/levelball/img/conf.png')
+        self.imageSTOP = gtk.image_new_from_file('/home/opt/levelball/img/stop_48.png')
+        self.imageSTART = gtk.image_new_from_file('/home/opt/levelball/img/go_48.png')
         self.area = gtk.DrawingArea()
         self.area.set_size_request(300, 54)
 #        self.drawable = self.area.window
@@ -145,14 +147,21 @@ class levelplugin(hildondesktop.HomePluginItem):
         self.gc = self.style1.fg_gc[gtk.STATE_NORMAL]
         self.area.connect("expose-event", self.expose)
          
-        self.button = gtk.Button(label="Start")
+        self.button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        self.button.set_label("")
+        self.button.set_image(self.imageSTART)
+        self.button.set_image_position(gtk.POS_LEFT)
         self.button.connect("clicked", self.start)
-        self.button2 = gtk.Button(label="Stop")
+        
+        self.button2 = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        self.button2.set_label("")
+        self.button2.set_image(self.imageSTOP)
+        self.button2.set_image_position(gtk.POS_LEFT)
         self.button2.connect("clicked", self.stop)
+#        self.button3.set_size_request(50,50)
         self.button3 = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
- #       self.button3.set_size_request(50,50)
         self.button3.set_label("")
-        self.button3.set_image(self.imageP)
+        self.button3.set_image(self.imageCONF)
         self.button3.set_image_position(gtk.POS_LEFT)
         self.button3.connect("clicked", GD_dialog_show)   
         
